RGCN
====

.. currentmodule:: pykeen.models

.. autoclass:: RGCN
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~RGCN.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~RGCN.post_parameter_update
      ~RGCN.score_hrt

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: post_parameter_update
   .. automethod:: score_hrt
